aboutsummaryrefslogtreecommitdiffhomepage
path: root/test/matrixmanip.cpp
diff options
context:
space:
mode:
authorGravatar Benoit Jacob <jacob.benoit.1@gmail.com>2007-10-12 05:15:25 +0000
committerGravatar Benoit Jacob <jacob.benoit.1@gmail.com>2007-10-12 05:15:25 +0000
commit3654ee8b07ae4d2ce6167768f9ab8a52456c462b (patch)
tree906ab0b2ab49426d63ed976f7384672a4f33ddae /test/matrixmanip.cpp
parent0d44c0906bedf9c3b66b38e9fc1d42a6d24f25cb (diff)
SVN_SILENT:
repair some damage made by the automatic search and replace used in the prefix->namespace move
Diffstat (limited to 'test/matrixmanip.cpp')
-rw-r--r--test/matrixmanip.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/matrixmanip.cpp b/test/matrixmanip.cpp
index c8863d183..eba184179 100644
--- a/test/matrixmanip.cpp
+++ b/test/matrixmanip.cpp
@@ -1,19 +1,19 @@
// This file is part of gen, a lightweight C++ template library
// for linear algebra. gen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
// gen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
//
// gen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along
// with gen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// As a special exception, if other files instantiate templates or use macros
@@ -42,7 +42,7 @@ template<typename MatrixType> void matrixManip(const MatrixType& m)
a.minor(i, j) -= a.block(1, rows-1, 1, cols-1).eval();
}
-void genTest::testMatrixManip()
+void EigenTest::testMatrixManip()
{
matrixManip(Matrix<int, 2, 3>());
matrixManip(Matrix<double, 3, 3>());
@@ -1,19 +1,19 @@
-// This file is part of gen, a lightweight C++ template library
-// for linear algebra. gen itself is part of the KDE project.
+// This file is part of Eigen, a lightweight C++ template library
+// for linear algebra. Eigen itself is part of the KDE project.
//
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
@@ -1,19 +1,19 @@
// Copyright (C) 2006-2007 Benoit Jacob <jacob@math.jussieu.fr>
//
-// gen is free software; you can redistribute it and/or modify it under the
+// Eigen is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 or (at your option) any later version.
@@ -1,19 +1,19 @@
// Foundation; either version 2 or (at your option) any later version.
//
-// gen is distributed in the hope that it will be useful, but WITHOUT ANY
+// Eigen is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
@@ -1,19 +1,19 @@
//
// You should have received a copy of the GNU General Public License along
-// with gen; if not, write to the Free Software Foundation, Inc., 51
+// with Eigen; if not, write to the Free Software Foundation, Inc., 51
// Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//